@@ -3,17 +3,17 @@ from .madness import ti, li
 from .create import Investigator
 from .san_check import sc
 
-from nonebot import on_command
+from nonebot.plugin import on_startswith
 from nonebot.adapters.cqhttp import Bot, Event
 
-rdhelp = on_command(".help", priority=2)
-stcommand = on_command(".st", priority=2)
-encommand = on_command(".en", priority=2)
-ticommand = on_command(".ti", priority=2)
-licommand = on_command(".li", priority=2)
-coc = on_command(".coc", priority=2)
-sccommand = on_command(".sc", priority=2)
-rdcommand = on_command(".", priority=3)
+rdhelp = on_startswith(".help", priority=2)
+stcommand = on_startswith(".st", priority=2)
+encommand = on_startswith(".en", priority=2)
+ticommand = on_startswith(".ti", priority=2)
+licommand = on_startswith(".li", priority=2)
+coc = on_startswith(".coc", priority=2)
+sccommand = on_startswith(".sc", priority=2)
+rdcommand = on_startswith(".", priority=3)
 
 
 @rdhelp.handle()
@@ -28,13 +28,13 @@ async def stcommandhandler(bot: Bot):
 
 @encommand.handle()
 async def enhandler(bot: Bot, event: Event):
-    args = str(event.get_message()).strip()
+    args = str(event.get_message())[3:].strip()
     await encommand.finish(en(args))
 
 
 @rdcommand.handle()
 async def rdcommandhandler(bot: Bot, event: Event):
-    args = str(event.get_message()).strip()
+    args = str(event.get_message())[1:].strip()
     uid = event.get_session_id()
     if args and not("." in args):
         rrd = rd(args)
@@ -46,7 +46,7 @@ async def rdcommandhandler(bot: Bot, event: Event):
 
 @coc.handle()
 async def cochandler(bot: Bot, event: Event):
-    args = str(event.get_message()).strip()
+    args = str(event.get_message())[4:].strip()
     try:
         args = int(args)
     except:
@@ -68,5 +68,5 @@ async def licommandhandler(bot: Bot):
 
 @sccommand.handle()
 async def schandler(bot: Bot, event: Event):
-    args = str(event.get_message()).strip()
+    args = str(event.get_message())[3:].strip()
     await sccommand.finish(sc(args.lower()))
